@@ -27,6 +27,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
 
@@ -64,7 +67,7 @@ _gdbm_get_bucket (dbf, dir_index)
      gdbm_file_info *dbf;
      word_t dir_index;
 {
-  word_t bucket_adr;	/* The address of the correct hash bucket.  */
+  off_t bucket_adr;	/* The address of the correct hash bucket.  */
   int   num_bytes;	/* The number of bytes read. */
   off_t	file_pos;	/* The return address for lseek. */
   register int index;	/* Loop index. */
@@ -73,22 +76,25 @@ _gdbm_get_bucket (dbf, dir_index)
   dbf->bucket_dir = dir_index;
   bucket_adr = dbf->dir [dir_index];
   
-  if (dbf->bucket_cache == NULL) {
-    if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
-      _gdbm_fatal(dbf, "couldn't init cache");
-  }
+  if (dbf->bucket_cache == NULL)
+    {
+      if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
+        _gdbm_fatal(dbf, "couldn't init cache");
+    }
 
   /* Is that one is not already current, we must find it. */
   if (dbf->cache_entry->ca_adr != bucket_adr)
     {
       /* Look in the cache. */
-      for (index = 0; index < dbf->cache_size; index++) {
-	if (dbf->bucket_cache[index].ca_adr == bucket_adr) {
-	    dbf->bucket = dbf->bucket_cache[index].ca_bucket;
-	    dbf->cache_entry = &dbf->bucket_cache[index];
-	    return;
-	}
-      }
+      for (index = 0; index < dbf->cache_size; index++)
+        {
+	  if (dbf->bucket_cache[index].ca_adr == bucket_adr)
+	    {
+	      dbf->bucket = dbf->bucket_cache[index].ca_bucket;
+	      dbf->cache_entry = &dbf->bucket_cache[index];
+	      return;
+	    }
+        }
 
       /* It is not in the cache, read it from the disk. */
       dbf->last_read = (dbf->last_read + 1) % dbf->cache_size;
@@ -132,15 +138,15 @@ _gdbm_split_bucket (dbf, next_insert)
   off_t        adr_1;		/* File address of the new bucket 1. */
   avail_elem   old_bucket;	/* Avail Struct for the old bucket. */
 
-  word_t      dir_start0;	/* Used in updating the directory. */
-  word_t      dir_start1;
-  word_t      dir_end;
+  off_t        dir_start0;	/* Used in updating the directory. */
+  off_t        dir_start1;
+  off_t        dir_end;
 
-  word_t      *new_dir;		/* Pointer to the new directory. */
-  off_t       dir_adr; 	/* Address of the new directory. */
-  word_t      dir_size;	/* Size of the new directory. */
-  word_t      old_adr[31]; 	/* Address of the old directories. */
-  word_t      old_size[31]; 	/* Size of the old directories. */
+  off_t       *new_dir;		/* Pointer to the new directory. */
+  off_t        dir_adr; 	/* Address of the new directory. */
+  int          dir_size;	/* Size of the new directory. */
+  off_t        old_adr[31]; 	/* Address of the old directories. */
+  int          old_size[31]; 	/* Size of the old directories. */
   int	       old_count;	/* Number of old directories. */
 
   int          index;		/* Used in array indexing. */
@@ -153,10 +159,11 @@ _gdbm_split_bucket (dbf, next_insert)
   /* No directories are yet old. */
   old_count = 0;
 
-  if (dbf->bucket_cache == NULL) {
-    if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
-      _gdbm_fatal(dbf, "couldn't init cache");
-  }
+  if (dbf->bucket_cache == NULL)
+    {
+      if(_gdbm_init_cache(dbf, DEFAULT_CACHESIZE) == -1)
+        _gdbm_fatal(dbf, "couldn't init cache");
+    }
 
   while (dbf->bucket->count == dbf->header->bucket_elems)
     {
@@ -194,10 +201,10 @@ _gdbm_split_bucket (dbf, next_insert)
 	{
 	  dir_size = dbf->header->dir_size * 2;
 	  dir_adr  = _gdbm_alloc (dbf, dir_size);
-	  new_dir  = (word_t *) malloc (dir_size);
+	  new_dir  = (off_t *) malloc (dir_size);
 	  if (new_dir == NULL) _gdbm_fatal (dbf, "malloc error");
 	  for (index = 0;
-	  	index < dbf->header->dir_size/sizeof (word_t); index++)
+	  	index < dbf->header->dir_size/sizeof (off_t); index++)
 	    {
 	      new_dir[2*index]   = dbf->dir[index];
 	      new_dir[2*index+1] = dbf->dir[index];
