@@ -29,11 +29,17 @@
 
 *************************************************************************/
 
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
+
 /* not much of a routine, but should be a function for compatibility. */
 
-int dbm_rdonly(dbf)
+int
+dbm_rdonly(dbf)
     gdbm_file_info *dbf;
 {
   return (dbf->read_write == GDBM_READER);
