@@ -1,7 +1,7 @@
 /* falloc.c - The file space management routines for dbm. */
 
 /*  This file is part of GDBM, the GNU data base manager, by Philip A. Nelson.
-    Copyright (C) 1990, 1991, 1993  Free Software Foundation, Inc.
+    Copyright (C) 1990, 1991, 1993, 1994  Free Software Foundation, Inc.
 
     GDBM is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,15 @@
        
 *************************************************************************/
 
+
+/* AIX demands this be the very first thing in the file. */
+#if !defined(__GNUC__) && defined(_AIX)
+ #pragma alloca
+#endif
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
 
@@ -69,12 +78,17 @@ _gdbm_alloc (dbf, num_bytes)
   /* If we did not find some space, we have more work to do. */
   if (av_el.av_size == 0)
     {
-     /* Is the header avail block empty and there is something on the stack. */
-      if (dbf->header->avail.count == 0 && dbf->header->avail.next_block != 0)
-	pop_avail_block (dbf);
-      
-      /* Get another full block from end of file. */
-      av_el = get_block (num_bytes, dbf);
+      /* Is the header avail block empty and there is something on the stack. */
+      if ((dbf->header->avail.count == 0)
+          && (dbf->header->avail.next_block != 0))
+        pop_avail_block (dbf);
+
+      /* check the header avail table next */
+      av_el = get_elem (num_bytes, dbf->header->avail.av_table,
+      			&dbf->header->avail.count);
+      if (av_el.av_size == 0)
+        /* Get another full block from end of file. */
+        av_el = get_block (num_bytes, dbf);
 
       dbf->header_changed = TRUE;
     }
@@ -332,6 +346,8 @@ _gdbm_put_av_elem (new_el, av_table, av_count)
 
 
 
+
+
 /* Get_block "allocates" new file space and the end of the file.  This is
    done in integral block sizes.  (This helps insure that data smaller than
    one block size is in a single block.)  Enough blocks are allocated to
@@ -398,5 +414,3 @@ adjust_bucket_avail (dbf)
       dbf->bucket_changed = TRUE;
     }
 }
-
-
