@@ -27,6 +27,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 
 
@@ -155,4 +158,3 @@ _gdbm_findkey (dbf, key, dptr, new_hash_val)
   return -1;
 
 }
-
