@@ -27,6 +27,14 @@
 *************************************************************************/
 
 
+/* AIX demands this be the very first thing in the file. */
+#if !defined(__GNUC__) && defined(_AIX)
+ #pragma alloca
+#endif
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
 
@@ -71,5 +79,3 @@ gdbm_fetch (dbf, key)
   if (return_val.dptr == NULL) gdbm_errno = GDBM_ITEM_NOT_FOUND;
   return return_val;
 }
-
-
