@@ -27,6 +27,14 @@
 *************************************************************************/
 
 
+/* AIX demands this be the very first thing in the file. */
+#if !defined(__GNUC__) && defined(_AIX)
+ #pragma alloca
+#endif
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
 
@@ -213,7 +221,7 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
       dbf->header->block_size = file_block_size;
      
       /* Create the initial hash table directory.  */
-      dbf->header->dir_size = 8 * sizeof (word_t);
+      dbf->header->dir_size = 8 * sizeof (off_t);
       dbf->header->dir_bits = 3;
       while (dbf->header->dir_size < dbf->header->block_size)
 	{
@@ -230,7 +238,7 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
 	}
 
       /* Allocate the space for the directory. */
-      dbf->dir = (word_t *) malloc (dbf->header->dir_size);
+      dbf->dir = (off_t *) malloc (dbf->header->dir_size);
       if (dbf->dir == NULL)
 	{
 	  gdbm_close (dbf);
@@ -244,7 +252,16 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
 	(dbf->header->block_size - sizeof (hash_bucket))
 	/ sizeof (bucket_element) + 1;
       dbf->header->bucket_size  = dbf->header->block_size;
+#if !defined(sgi)
       dbf->bucket = (hash_bucket *) (alloca (dbf->header->bucket_size));
+#else	/* sgi */
+      /* The SGI C compiler doesn't accept the previous form. */
+      {
+        hash_bucket *ptr;
+	ptr = (hash_bucket *) (alloca (dbf->header->bucket_size));
+	dbf->bucket = ptr;
+      }
+#endif	/* sgi */
       if (dbf->bucket == NULL)
 	{
 	  gdbm_close (dbf);
@@ -257,7 +274,7 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
       dbf->bucket->bucket_avail[0].av_size = dbf->header->block_size;
 
       /* Set table entries to point to hash buckets. */
-      for (index = 0; index < dbf->header->dir_size / sizeof (word_t); index++)
+      for (index = 0; index < dbf->header->dir_size / sizeof (off_t); index++)
 	dbf->dir[index] = 2*dbf->header->block_size;
 
       /* Initialize the active avail block. */
@@ -343,7 +360,7 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
 	}
 	
       /* Allocate space for the hash table directory.  */
-      dbf->dir = (word_t *) malloc (dbf->header->dir_size);
+      dbf->dir = (off_t *) malloc (dbf->header->dir_size);
       if (dbf->dir == NULL)
 	{
 	  gdbm_close (dbf);
@@ -387,35 +404,40 @@ gdbm_open (file, block_size, flags, mode, fatal_func)
 }
 
 /* initialize the bucket cache. */
-int _gdbm_init_cache(dbf, size)
+int
+_gdbm_init_cache(dbf, size)
     gdbm_file_info *dbf;
     int size;
 {
 register int index;
 
-  if (dbf->bucket_cache == NULL) {
-    dbf->bucket_cache = (cache_elem *) malloc(sizeof(cache_elem) * size);
-    if(dbf->bucket_cache == NULL) {
-      gdbm_errno = GDBM_MALLOC_ERROR;
-      return(-1);
-    }
-    dbf->cache_size = size;
+  if (dbf->bucket_cache == NULL)
+    {
+      dbf->bucket_cache = (cache_elem *) malloc(sizeof(cache_elem) * size);
+      if(dbf->bucket_cache == NULL)
+        {
+          gdbm_errno = GDBM_MALLOC_ERROR;
+          return(-1);
+        }
+      dbf->cache_size = size;
 
-    for(index = 0; index < size; index++) {
-      (dbf->bucket_cache[index]).ca_bucket
+      for(index = 0; index < size; index++)
+        {
+          (dbf->bucket_cache[index]).ca_bucket
             = (hash_bucket *) malloc (dbf->header->bucket_size);
-      if ((dbf->bucket_cache[index]).ca_bucket == NULL) {
-        gdbm_errno = GDBM_MALLOC_ERROR;
-	return(-1);
-      }
-      (dbf->bucket_cache[index]).ca_adr = 0;
-      (dbf->bucket_cache[index]).ca_changed = FALSE;
-      (dbf->bucket_cache[index]).ca_data.hash_val = -1;
-      (dbf->bucket_cache[index]).ca_data.elem_loc = -1;
-      (dbf->bucket_cache[index]).ca_data.dptr = NULL;
+          if ((dbf->bucket_cache[index]).ca_bucket == NULL)
+	    {
+              gdbm_errno = GDBM_MALLOC_ERROR;
+	      return(-1);
+            }
+          (dbf->bucket_cache[index]).ca_adr = 0;
+          (dbf->bucket_cache[index]).ca_changed = FALSE;
+          (dbf->bucket_cache[index]).ca_data.hash_val = -1;
+          (dbf->bucket_cache[index]).ca_data.elem_loc = -1;
+          (dbf->bucket_cache[index]).ca_data.dptr = NULL;
+        }
+      dbf->bucket = dbf->bucket_cache[0].ca_bucket;
+      dbf->cache_entry = &dbf->bucket_cache[0];
     }
-    dbf->bucket = dbf->bucket_cache[0].ca_bucket;
-    dbf->cache_entry = &dbf->bucket_cache[0];
-  }
   return(0);
 }
