@@ -27,6 +27,14 @@
 ************************************************************************/
 
 
+/* AIX demands this be the very first thing in the file. */
+#if !defined(__GNUC__) && defined(_AIX)
+ #pragma alloca
+#endif
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
 #include "extern.h"
@@ -135,7 +143,7 @@ gdbm_reorganize (dbf)
 	      gdbm_errno = GDBM_REORGANIZE_FAILED;
 	      unlink (new_name);
 	      return -1;
-	    };
+	    }
  	}
       else
  	{
@@ -205,5 +213,3 @@ gdbm_reorganize (dbf)
 
   return 0;
 }
-
-
