@@ -27,11 +27,14 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
 
 /* Special extern for this file. */
-extern char *_gdbm_read_entry ();
+extern char *_gdbm_read_entry _ARGS((gdbm_file_info *, int));
 
 
 /* Find and read the next entry in the hash structure for DBF starting
@@ -60,12 +63,12 @@ get_next_key (dbf, elem_loc, return_val)
 
 	  /* Find the next bucket.  It is possible several entries in
 	     the bucket directory point to the same bucket. */
-	  while (dbf->bucket_dir < dbf->header->dir_size / sizeof (word_t)
+	  while (dbf->bucket_dir < dbf->header->dir_size / sizeof (off_t)
 		 && dbf->cache_entry->ca_adr == dbf->dir[dbf->bucket_dir])
 	    dbf->bucket_dir++;
 
 	  /* Check to see if there was a next bucket. */
-	  if (dbf->bucket_dir < dbf->header->dir_size / sizeof (word_t))
+	  if (dbf->bucket_dir < dbf->header->dir_size / sizeof (off_t))
 	    _gdbm_get_bucket (dbf, dbf->bucket_dir);	      
 	  else
 	    /* No next key, just return. */
