@@ -27,6 +27,8 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
 
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
