@@ -28,20 +28,29 @@
 *************************************************************************/
 
 
+/* AIX demands this be the very first thing in the file. */
+#if !defined(__GNUC__) && defined(_AIX)
+ #pragma alloca
+#endif
+
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include "gdbmdefs.h"
 #include "gdbmerrno.h"
 #include "extern.h"
 
 #include "getopt.h"
 
-extern char * gdbm_version;
+extern const char * gdbm_version;
 
-extern char *gdbm_strerror _ARGS((gdbm_error));
+extern const char *gdbm_strerror _ARGS((gdbm_error));
 
 gdbm_file_info *gdbm_file;
 
 /* Debug procedure to print the contents of the current hash bucket. */
-void print_bucket (bucket, mesg)
+void
+print_bucket (bucket, mesg)
      hash_bucket *bucket;
      char *mesg;
 {
@@ -66,7 +75,8 @@ void print_bucket (bucket, mesg)
 }
 
 
-void _gdbm_print_avail_list (dbf)
+void
+_gdbm_print_avail_list (dbf)
      gdbm_file_info *dbf;
 {
   int temp;
@@ -106,7 +116,8 @@ void _gdbm_print_avail_list (dbf)
     }
 }
 
-void _gdbm_print_bucket_cache (dbf)
+void
+_gdbm_print_bucket_cache (dbf)
      gdbm_file_info *dbf;
 {
   register int index;
@@ -128,7 +139,8 @@ void _gdbm_print_bucket_cache (dbf)
     printf("Bucket cache has not been initialized.\n");
 }
 
-void usage (s)
+void
+usage (s)
      char *s;
 {
   printf(
@@ -142,7 +154,8 @@ void usage (s)
    The commands are single letter commands.  The user is prompted for all other
    information.  See the help command (?) for a list of all commands. */
 
-int main (argc, argv)
+int
+main (argc, argv)
      int argc;
      char *argv[];
 
@@ -198,24 +211,31 @@ int main (argc, argv)
   key_data.dptr = NULL;
   data_data.dptr = data_line;
 
-  if (reader) {
-    gdbm_file = gdbm_open (file_name, block_size, GDBM_READER, 00664, NULL);
-  } else if (newdb) {
-    gdbm_file =
+  if (reader)
+    {
+      gdbm_file = gdbm_open (file_name, block_size, GDBM_READER, 00664, NULL);
+    }
+  else if (newdb)
+    {
+      gdbm_file =
     	gdbm_open (file_name, block_size, GDBM_NEWDB | fast, 00664, NULL);
-  } else {
-    gdbm_file =
+    }
+  else
+    {
+      gdbm_file =
     	gdbm_open (file_name, block_size, GDBM_WRCREAT | fast, 00664, NULL);
-  }
-  if (gdbm_file == NULL) {
-    printf("gdbm_open failed, %s\n", gdbm_strerror(gdbm_errno));
-    exit (2);
-  }
+    }
+  if (gdbm_file == NULL)
+    {
+      printf("gdbm_open failed, %s\n", gdbm_strerror(gdbm_errno));
+      exit (2);
+    }
 
-  if (gdbm_setopt(gdbm_file, GDBM_CACHESIZE, &cache_size, sizeof(int)) == -1) {
-    printf("gdbm_setopt failed, %s\n", gdbm_strerror(gdbm_errno));
-    exit(2);
-  }
+  if (gdbm_setopt(gdbm_file, GDBM_CACHESIZE, &cache_size, sizeof(int)) == -1)
+    {
+      printf("gdbm_setopt failed, %s\n", gdbm_strerror(gdbm_errno));
+      exit(2);
+    }
 
   /* Welcome message. */
   printf ("\nWelcome to the gdbm test program.  Type ? for help.\n\n");
