@@ -27,6 +27,9 @@
 *************************************************************************/
 
 
+/* include system configuration before all else. */
+#include "autoconf.h"
+
 #include <stdio.h>
 #include <sys/types.h>
 #if HAVE_FILE_H
@@ -51,7 +54,8 @@
    information.  The commands are q (quit), f (fetch), s (store), d (delete),
    1 (firstkey), n (nextkey) and h (hash function). */
 
-int main (argc, argv)
+int
+main (argc, argv)
      int argc;
      char *argv[];
 {
